#region Using declarations
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.ComponentModel.DataAnnotations;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Input;
using System.Windows.Media;
using System.Xml.Serialization;
using NinjaTrader.Cbi;
using NinjaTrader.Gui;
using NinjaTrader.Gui.Chart;
using NinjaTrader.Gui.SuperDom;
using NinjaTrader.Gui.Tools;
using NinjaTrader.Data;
using NinjaTrader.NinjaScript;
using NinjaTrader.Core.FloatingPoint;
using NinjaTrader.NinjaScript.DrawingTools;
#endregion

//This namespace holds Indicators in this folder and is required. Do not change it. 
namespace NinjaTrader.NinjaScript.Indicators
{
	public class JTRelativeVolumeNT8 : Indicator
	{
		private double	[]	avgVolAtTime = null;
		private int		[]	numberOfOccurences = null;
		private double 	tempVol = 0;
		private double	cVol = 0;
		private int 	tempNOC = 0;
		private int	barCounter = 0;
		private double cumulativeVolume = 0;		

		protected override void OnStateChange()
		{
			if (State == State.SetDefaults)
			{
				Description									= @"Custom indicator for traderstom2012 from futures.io, converting script from NT7 to NT8";
				Name										= "JTRelativeVolumeNT8";
				Calculate									= Calculate.OnEachTick;
				IsOverlay									= false;
				DisplayInDataBox							= true;
				DrawOnPricePanel							= true;
				DrawHorizontalGridLines						= true;
				DrawVerticalGridLines						= true;
				PaintPriceMarkers							= true;
				ScaleJustification							= NinjaTrader.Gui.Chart.ScaleJustification.Right;
				//Disable this property if your indicator requires custom values that cumulate with each new market data event. 
				//See Help Guide for additional information.
				IsSuspendedWhileInactive					= true;
				AddPlot(new Stroke(Brushes.Plum, 2), PlotStyle.Bar, "CumulativeVolumeDiff");
				avgVolAtTime		= new double[4000];
				numberOfOccurences	= new int[4000];
			}
			else if (State == State.Configure)
			{

			}
		}

		protected override void OnBarUpdate()
		{
			if (IsFirstTickOfBar) 
			{
				if (Bars.IsFirstBarOfSession)
				{
					barCounter = 0;
					cVol = 0;
				}
				else
					cVol = cVol + Volume[1];
				barCounter++;
				tempNOC = numberOfOccurences[barCounter];
				tempVol = avgVolAtTime[barCounter] * numberOfOccurences[barCounter];
			} 
			
            cumulativeVolume = (cVol + Volume[0]);
            numberOfOccurences[barCounter] = tempNOC + 1;
			avgVolAtTime[barCounter] = (cVol + Volume[0] + tempVol) / numberOfOccurences[barCounter];
			CumulativeVolumeDiff[0] = (cumulativeVolume - avgVolAtTime[barCounter]);
		}

		#region Properties
		[Browsable(false)]
		[XmlIgnore]
		public Series<double> CumulativeVolumeDiff
		{
			get { return Values[0]; }
		}
		#endregion
	}
}

#region NinjaScript generated code. Neither change nor remove.

namespace NinjaTrader.NinjaScript.Indicators
{
	public partial class Indicator : NinjaTrader.Gui.NinjaScript.IndicatorRenderBase
	{
		private JTRelativeVolumeNT8[] cacheJTRelativeVolumeNT8;
		public JTRelativeVolumeNT8 JTRelativeVolumeNT8()
		{
			return JTRelativeVolumeNT8(Input);
		}

		public JTRelativeVolumeNT8 JTRelativeVolumeNT8(ISeries<double> input)
		{
			if (cacheJTRelativeVolumeNT8 != null)
				for (int idx = 0; idx < cacheJTRelativeVolumeNT8.Length; idx++)
					if (cacheJTRelativeVolumeNT8[idx] != null &&  cacheJTRelativeVolumeNT8[idx].EqualsInput(input))
						return cacheJTRelativeVolumeNT8[idx];
			return CacheIndicator<JTRelativeVolumeNT8>(new JTRelativeVolumeNT8(), input, ref cacheJTRelativeVolumeNT8);
		}
	}
}

namespace NinjaTrader.NinjaScript.MarketAnalyzerColumns
{
	public partial class MarketAnalyzerColumn : MarketAnalyzerColumnBase
	{
		public Indicators.JTRelativeVolumeNT8 JTRelativeVolumeNT8()
		{
			return indicator.JTRelativeVolumeNT8(Input);
		}

		public Indicators.JTRelativeVolumeNT8 JTRelativeVolumeNT8(ISeries<double> input )
		{
			return indicator.JTRelativeVolumeNT8(input);
		}
	}
}

namespace NinjaTrader.NinjaScript.Strategies
{
	public partial class Strategy : NinjaTrader.Gui.NinjaScript.StrategyRenderBase
	{
		public Indicators.JTRelativeVolumeNT8 JTRelativeVolumeNT8()
		{
			return indicator.JTRelativeVolumeNT8(Input);
		}

		public Indicators.JTRelativeVolumeNT8 JTRelativeVolumeNT8(ISeries<double> input )
		{
			return indicator.JTRelativeVolumeNT8(input);
		}
	}
}

#endregion
